      PROGRAM STRMDEPL08
C     Version: 1.0, June, 2008   
C
C      ********************************************************
C      *                                                      *
C      *               *** STRMDEPL08      ***                *
C      *               modifications to                       *
C      *               *** STRMDEPL        ***                *
C      *                                                      *
C      *    ONE-DIMENSIONAL MODEL OF STREAMFLOW DEPLETION     *
C      *                                                      *
C      *        BY WELLS, BASED ON ANALYTICAL SOLUTIONS       *
C      *                                                      *
C      *    DEVELOPED BY JENKINS (1968) AND HANTUSH (1965)    *
C      *                                                      *
C      *            MODIFIED TO INCLUDE 2-D (AREAL)           *
C      *           SOLUTIONS BY HUNT (1999) AND (2003)        *
C      *                                                      *
C      *           MODIFIED BY H.W. REEVES                    *
C      *        USGS MICHIGAN WATER SCIENCE CENTER            *
C      *                                                      *
C      *                                                      *
C      ********************************************************
C
C
C      Although this program has been used by the U.S. Geological
C      Survey, no warranty, expressed or implied, is made by the 
C      USGS as to the accuracy and functioning of the program and
C      related program material, nor shall the fact of distribution
C      constitute any such warranty, and no responsibility is
C      assumed by the USGS in connection therewith
C
C
C---INPUT VARIABLES:
C   LINE 1: TITLE:   Title of problem
C   LINE 2: WELLID:  Well identifier
C   LINE 3: XWELL:   Distance of well from stream, in feet
C           DIFFUS:  Diffusivity of aquifer, in square feet per second 
C                    (if ISOLN<=1), transmissivity if ISOLN > 1
C           ISOLN:   Flag for analytical solution used:
C                    0 = fully penetrating, no streambank resistance (Jenkins, 1968)
C                    1 = fully penetrating with streambank leakance (Hantush, 1965)
C                    2 = partially penetrating with resistance (Hunt, 1999)
C                    3 = stream in an aquitard over a leaky aquifer (Hunt, 2003)
C           SLEAK:   Streambank leakance, in feet (if 1), 
C                     LAMBDA in ft/sec if ISOLN=2, or ISOLN=3 with K'=0
C           STOR:    Storativity, (ISOLN >1)
C           SIGMA:   Specific yield (ISOLN=3)
C           BPP:     Streambottom to aquifer top in feet (ISOLN=3)
C           BP:      Thickness of semi-confining layer in feet (ISOLN=3)
C           KPRIME:  Hydraulic conductivity of upper layer (ft/sec), ISOLN=3
C           STRWTH:  Stream width in feet, ISOLN=3
C           DELT:    Time step size in days - if zero is read, it is set to 1 
C                    Analytical solution, so time step should match interval
C                    of pumping rate changes.  Must be uniform for 
C                    the input pumping record.
C           
C   LINE 4: INTIME:  Number of pumping days prior to start of analysis
C           QWINIT:  Pumping rate prior to start of analysis, in cubic
C                     feet per second
C   LINE 5: NPD:     Number of steps when pumping rate may change in analysis
C   LINE 6: CDATE(I) Date for time-step (day) I with hours added
C           QWELL(I) Pumping rate for time-step (day) I, in cubic feet
C                     per second
C---SOLUTION VARIABLES:
C   SDF:     Streamflow depletion factor, in day (converted from seconds)
C   DELQ(I): Difference in pumping rates between time steps I and I-1
C             (DELQ(1) equals QWELL(1)), in cubic feet per second
C   QSINT:   Streamflow-depletion rate due to pumping prior to start of
C             analysis, in cubic feet per second
C   QS(I):   Calculated streamflow-depletion rate for day I, in cubic
C             feet per second
C   T:       Simulation time, in days
C   U,W:     Hydraulic groupings for solutions (see Hantush, 1965)
C   GP(I):   Gauss points used in numerical integration 
C   WT(I):   Weights used in numerical integration
C
C---SPECIFICATIONS
C
C---THE FOLLOWING CARD MUST BE CHANGED IF PROBLEM DIMENSIONS ARE
C   GREATER THAN 30,000. ALSO CHANGE VALUE OF IMAXX IN
C   SUBROUTINE DATAIO
      PARAMETER (IMAXX=30000)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION DELQ(IMAXX),QWELL(IMAXX),QS(IMAXX)
      CHARACTER CDATE(IMAXX)*10
      DOUBLE PRECISION GP(7)/-0.949107912342759, -0.741531185599394, 
     & -0.405845151377397, 0.0D0, 0.405845151377397, 
     &  0.741531185599394, 0.949107912342759/
      DOUBLE PRECISION WT(7)/0.129484966168870, 0.279705391489277, 
     &  0.381830050505119, 0.417959183673469, 0.381830050505119,
     &  0.279705391489277, 0.129484966168870/
C
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ XWELL,DIFFUS,SLEAK,QWINIT
      COMMON /PAR2/ ISOLN,INTIME,NPD
      COMMON /PAR7/ CDATE,QWELL
      COMMON /HUNT/ TRANS, STOR, SIGMA, RKPRME, BP
      COMMON /TSTEP/ DELT
C
C
C1--OPEN INPUT, RESULT, AND PLOT FILES
C     try to get file names from command line first (Call AFILE added for GenScn extension)
      CALL AFILE(IPLOT)
      IF (IPLOT.EQ.-1) THEN
C       could not get file names from command line, so prompt for them
        CALL OFILE(IPLOT)
      END IF
C
C2--READ AND WRITE INPUT DATA
      CALL DATAIO
C
C3--DEFINE PARAMETERS. 
C    Note that DIFFUS is converted from seconds to days.
      DIFFUS=DIFFUS*86400.0D0
      SDF=(XWELL*XWELL)/DIFFUS
C-- HUNT PARAMETERS (CONVERT T AND K' TO DAYS)
      TRANS=TRANS*86400.0D0
      RKPRME=RKPRME*86400.0D0
      IF(ISOLN.GE.2)SLEAK=SLEAK*86400.0D0
      IF(ISOLN.EQ.3)THEN
        DEPS=STOR/SIGMA
        DLAM=SLEAK*XWELL/TRANS
        DK=((RKPRME/BP)*XWELL**2)/TRANS
      ENDIF
C
      WRITE(IO,100)
C     WRITE(*,101)     Suppress execution message in GenScn Extension
C
C---CALCULATE THE INITIAL DEPLETION DUE TO PUMPING PRIOR TO
C    START OF ANALYSIS
       T=FLOAT(INTIME)
C---IF ISOLN=0, USE JENKINS (1968)
       IF(ISOLN.EQ.0)THEN
        U=DSQRT(SDF/(4.0D0*T))
        CALL EXERFC(0.0D0,U,Z1)
        QSINIT=QWINIT*Z1
       ENDIF
C---IF ISOLN=1, USE HANTUSH (1965)
       IF(ISOLN.EQ.1)THEN
        U=DSQRT(SDF/(4.0D0*T))
        W=(DSQRT(DIFFUS*T))/SLEAK
        C1= -(U*U) + (U+W)*(U+W)
        C2=U+W
        CALL EXERFC(0.0D0,U,Z1)
        CALL EXERFC(C1,C2,Z2)
        QSINIT=QWINIT*(Z1-Z2)
       ENDIF
C---IF ISOLN=2, USE HUNT (1999)
       IF(ISOLN .GE. 2)THEN
        Y=DSQRT((STOR*XWELL**2)/(4.0D0*TRANS*T))
        CALL EXERFC(0.0D0,Y,TERM1)
        X1=(SLEAK**2*T)/(4.0D0*STOR*TRANS)
        X2=(SLEAK*XWELL)/(2.0D0*TRANS)
        X=X1+X2
        Y1=DSQRT((SLEAK**2*T)/(4.0D0*STOR*TRANS))
        Y2=DSQRT((STOR*XWELL**2)/(4.0D0*TRANS*T))
        Y=Y1+Y2
        CALL EXERFC(X,Y,TERM2)
        QSINIT=QWINIT*(TERM1-TERM2)
       ENDIF
C---IF ISOLN=3, USE HUNT(2003) BY ADDING CORRECTION
       IF(ISOLN .EQ. 3)THEN
C      D-VARIABLES BELOW ARE DIMENSIONLESS VARIABLES FROM 2003 PAPER
C.......NUMERICAL INTEGRATION
        DT=(TRANS*T)/(STOR*XWELL**2)
        CORSUM=0.0D0
        DO IPT=1,7
C           ALPHA RANGES FROM 0 TO 1, GAUSS POINTS ARE FOR -1 TO 1
C           USE CHANGE OF VARIABLE TO GET CORRECT ALPHA CORRESPONDING TO GAUSS POINTS
            ALPHA=0.50D0+0.50D0*GP(IPT)
            CALL FTERM(DLAM,ALPHA,DT,F)
            CALL GTERM(DK,DEPS,ALPHA,DT,G)
            CORSUM=CORSUM+F*G*WT(IPT)
        ENDDO
C       THE "0.5" IN THE NEXT LINE IS FROM THE CHANGE IN RANGE OF INTEGRATION
C       IN THE GAUSSIAN QUADRATURE FROM -1 -> 1 TO 0 -> 1.
        IF(CORSUM .LT. 0.0)CORSUM=0.0
        CORREC=QWINIT*DLAM*CORSUM*0.50D0
        IF(CORREC .GT. QSINIT)CORREC=QSINIT
        QSINIT=QSINIT-CORREC
      ENDIF
C
      WRITE(IO,102)QSINIT
C
C---NOW, DO CONVOLUTION
C
C5--INITIALIZE DEPLETION ARRAY
       DO 5 I=1,NPD
        QS(I)=0.0D0
    5  CONTINUE
C
C6--CALCULATE THE TIME RATE OF CHANGE OF SYSTEM STRESS
       DELQ(1)=QWELL(1)-QWINIT
       DO 10 I=2,NPD
        DELQ(I)=QWELL(I)-QWELL(I-1)
   10  CONTINUE
C
C7--CALCULATE STREAMFLOW DEPLETIONS USING CONVOLUTION
       DO 15 JT=1,NPD
         SUM=0.0D0
C---COMPONENT A (QSINIT)--DEPLETION DUE TO THE CONSTANT PUMPING
C    RATE PRIOR TO START OF ANALYSIS
       T=FLOAT(INTIME)+FLOAT(JT)*DELT
C---IF ISOLN=0, USE JENKINS (1968)
       IF(ISOLN.EQ.0)THEN
        U=DSQRT(SDF/(4.0D0*T))
        CALL EXERFC(0.0D0,U,Z1)
        QSINIT=QWINIT*Z1
       ENDIF
C---IF ISOLN=1, USE HANTUSH (1965)
       IF(ISOLN.EQ.1)THEN
        U=DSQRT(SDF/(4.0D0*T))
        W=(DSQRT(DIFFUS*T))/SLEAK
        C1= -(U*U) + (U+W)*(U+W)
        C2=U+W
        CALL EXERFC(0.0D0,U,Z1)
        CALL EXERFC(C1,C2,Z2)
        QSINIT=QWINIT*(Z1-Z2)
       ENDIF
C---IF ISOLN=2, USE HUNT (1999)
       IF(ISOLN .GE. 2)THEN
        Y=DSQRT((STOR*XWELL**2)/(4.0D0*TRANS*T))
        CALL EXERFC(0.0D0,Y,TERM1)
        X1=(SLEAK**2*T)/(4.0D0*STOR*TRANS)
        X2=(SLEAK*XWELL)/(2.0D0*TRANS)
        X=X1+X2
        Y1=DSQRT((SLEAK**2*T)/(4.0D0*STOR*TRANS))
        Y2=DSQRT((STOR*XWELL**2)/(4.0D0*TRANS*T))
        Y=Y1+Y2
        CALL EXERFC(X,Y,TERM2)
        QSINIT=QWINIT*(TERM1-TERM2)
       ENDIF
C---IF ISOLN=3, USE HUNT(2003) BY ADDING CORRECTION TO PREV QSINIT
       IF(ISOLN .EQ. 3)THEN
C      D-VARIABLES BELOW ARE DIMENSIONLESS VARIABLES FROM 2003 PAPER
C.......NUMERICAL INTEGRATION
        DT=(TRANS*T)/(STOR*XWELL**2)
        CORSUM=0.0D0
        DO IPT=1,7
C           ALPHA RANGES FROM 0 TO 1, GAUSS POINTS ARE FOR -1 TO 1
C           USE CHANGE OF VARIABLE TO GET CORRECT ALPHA CORRESPONDING TO GAUSS POINTS
            ALPHA=0.50D0+0.50D0*GP(IPT)
            CALL FTERM(DLAM,ALPHA,DT,F)
            CALL GTERM(DK,DEPS,ALPHA,DT,G)
            CORSUM=CORSUM+F*G*WT(IPT)
        ENDDO
C       THE 0.5 IN THE NEXT LINE IS FROM THE CHANGE IN RANGE OF INTEGRATION
C       IN THE GAUSSIAN QUADRATURE FROM -1 -> 1 TO 0 -> 1.
        IF(CORSUM .LT. 0.0)CORSUM=0.0
        CORREC=QWINIT*DLAM*CORSUM*0.50D0
        IF(CORREC .GT. QSINIT)CORREC=QSINIT
        QSINIT=QSINIT-CORREC
      ENDIF
C
C---COMPONENT B (SUM)--DEPLETIONS DUE TO VARIABLE, DAILY
C    PUMPING RATES SINCE START OF ANALYSIS
        DO 20 KT=1,JT
         T=FLOAT(KT)*DELT
C---IF ISOLN=0, USE JENKINS (1968)
         IF(ISOLN.EQ.0)THEN
          U=DSQRT(SDF/(4.0D0*T))
          CALL EXERFC(0.0D0,U,Z1)
          SUM=SUM + DELQ(JT-KT+1)*Z1
         ENDIF
C---IF ISOLN=1, USE HANTUSH (1965)
         IF(ISOLN.EQ.1)THEN
          U=DSQRT(SDF/(4.0D0*T))
          W=(DSQRT(DIFFUS*T))/SLEAK
          C1= -(U*U) + (U+W)*(U+W)
          C2=U+W
          CALL EXERFC(0.0D0,U,Z1)
          CALL EXERFC(C1,C2,Z2)
          SUM=SUM + DELQ(JT-KT+1)*(Z1-Z2)
         ENDIF
C---IF ISOLN=2, USE HUNT (1999)
       IF(ISOLN .GE. 2)THEN
        Y=DSQRT((STOR*XWELL**2)/(4.0D0*TRANS*T))
        CALL EXERFC(0.0D0,Y,TERM1)
        X1=(SLEAK**2*T)/(4.0D0*STOR*TRANS)
        X2=(SLEAK*XWELL)/(2.0D0*TRANS)
        X=X1+X2
        Y1=DSQRT((SLEAK**2*T)/(4.0D0*STOR*TRANS))
        Y2=DSQRT((STOR*XWELL**2)/(4.0D0*TRANS*T))
        Y=Y1+Y2
        CALL EXERFC(X,Y,TERM2)
        SUM=SUM+DELQ(JT-KT+1)*(TERM1-TERM2)
       ENDIF
C---IF ISOLN=3, USE HUNT(2003) BY ADDING CORRECTION TO PREV QSINIT
       IF(ISOLN .EQ. 3)THEN
C      D-VARIABLES BELOW ARE DIMENSIONLESS VARIABLES FROM 2003 PAPER
C.......NUMERICAL INTEGRATION
        DT=(TRANS*T)/(STOR*XWELL**2)
        CORSUM=0.0D0
        DO IPT=1,7
C           ALPHA RANGES FROM 0 TO 1, GAUSS POINTS ARE FOR -1 TO 1
C           USE CHANGE OF VARIABLE TO GET CORRECT ALPHA CORRESPONDING TO GAUSS POINTS
            ALPHA=0.50D0+0.50D0*GP(IPT)
            CALL FTERM(DLAM,ALPHA,DT,F)
            CALL GTERM(DK,DEPS,ALPHA,DT,G)
            CORSUM=CORSUM+F*G*WT(IPT)
        ENDDO
C       THE 0.5 IN THE NEXT LINE IS FROM THE CHANGE IN RANGE OF INTEGRATION
C       IN THE GAUSSIAN QUADRATURE FROM -1 -> 1 TO 0 -> 1.
        IF(CORSUM .LT. 0.0)CORSUM=0.0
        SUM=SUM-DELQ(JT-KT+1)*DLAM*CORSUM*0.50D0
      ENDIF
   20   CONTINUE
C
C---NOW, ADD COMPONENTS A AND B FOR TOTAL DEPLETION QS(JT)
        QS(JT)=QSINIT + SUM
   15  CONTINUE
C
C9--WRITE RESULTS TO RESULT AND PLOT FILES
      WRITE(IO,103)
C
      IF(IPLOT.EQ.1)WRITE(IP,104)
C
      DO 80 I=1,NPD
       WRITE(IO,105)CDATE(I),QWELL(I),QS(I)
       IF(IPLOT.EQ.1)THEN
       WRITE(IP,106)CDATE(I),QWELL(I),QS(I)
       ENDIF
  80   CONTINUE
C
C---FORMAT STATEMENTS
  100 FORMAT(/,/,/,28X,'RESULTS',/,28X,'-------',/)
  101 FORMAT(/,3X,'Calculating aquifer responses ...',/)
  102 FORMAT(/,/,3X,'STREAMFLOW DEPLETION AT BEGINNING OF',
     2' ANALYSIS:',/,10X,F10.4,' cubic feet per second')
  103 FORMAT(/,/,16X,'PUMPING RATE    STREAMFLOW DEPLETION',/,
     26X,'DAY              (cubic feet per second)',/,
     3'      ---       ------------    --------------------')
  104 FORMAT(4X,'DATE',10X,'QWELL',9X,'QS')
  105 FORMAT(3X,A10,4X,F10.4,9X,F10.4)
  106 FORMAT(2X,A10,3X,F10.4,3X,F10.4)
C
C10-CLOSE INPUT/RESULT/PLOT FILES, STOP, AND END
      CLOSE(UNIT=IN)
      CLOSE(UNIT=IO)
      IF(IPLOT.EQ.1)CLOSE(UNIT=IP)
      
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE OFILE                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 04/21/00 A          *
C      *                                                      *
C       ******************************************************
C
C11-SUBROUTINE OFILE OPENS INPUT, RESULT, AND PLOT FILES
C
      SUBROUTINE OFILE(IPLOT)
C
C---SPECIFICATIONS
      CHARACTER*50 IFNAME, OFNAME, PFNAME
      INTEGER IN, IO, IP, N, IPLOT
      COMMON /IOUNIT/ IN,IO,IP
C
      IN = 15
      IO = 16
      IP = 17
C
C---READ INPUT, RESULT, AND PLOT FILE NAMES
   10 WRITE(*,2)
      READ(*,5) IFNAME
      N=LENCHR(IFNAME)
      IF(N.LT.1) GO TO 10
      OPEN(IN,FILE=IFNAME,STATUS='OLD')
C
   11 WRITE(*,3)
      READ(*,5) OFNAME
      N=LENCHR(OFNAME)
      IF(N.LT.1) GO TO 11
      OPEN(IO,FILE=OFNAME)
C
      WRITE(*,4)
      READ(*,5) PFNAME
      N=LENCHR(PFNAME)
      IF(N.LT.1)THEN
       IPLOT=0
       WRITE(*,6)
      ELSE
       IPLOT=1
       OPEN(IP,FILE=PFNAME)
      ENDIF
C
      WRITE(*,7)
C
C---FORMAT STATEMENTS
    2 FORMAT(3X,'Enter name of file containing input data:')
    3 FORMAT(3X,'Enter name of file for program results:')
    4 FORMAT(3X,'Enter name of plot file (return for no plot file):')
    5 FORMAT(A50)
    6 FORMAT(/,3X,'No plot file specified. Results will not be written',
     1' to a plot file.')
    7 FORMAT(/,3X,'File names have been read.')
C
C---RETURN AND END
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION LENCHR                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 04/21/00 A          *
C      *                                                      *
C       ******************************************************
C
C12-FUNCTION LENCHR CALCULATES THE LENGTH OF A CHARACTER STRING
C   (CODE FROM R. STEVE REGAN, USGS)
C
      INTEGER FUNCTION LENCHR
     I                       ( STRING )
C
      CHARACTER*(*) STRING
C
C     + + + ARGUMENT DEFINITIONS + + +
C     STRING - Input string to determine length of
C
C     + + + LOCAL VARIABLES + + +
      INTEGER MAX, I
C
C     + + + INTRINSICS + + +
      INTEGER LEN
      INTRINSIC LEN
C
C     + + + END SPECIFICATIONS + + +
C
      MAX = LEN(STRING)
      DO 10 I = MAX, 1, -1
        IF (STRING(I:I).NE.' ') THEN
          LENCHR = I
          GOTO 20
        ENDIF
   10 CONTINUE
      LENCHR = 0
C
   20 RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE DATAIO                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 05/02/07  HWR       *
C      *                                                      *
C       ******************************************************
C
C13-SUBROUTINE DATAIO READS INPUT DATA FROM THE INPUT FILE AND
C   WRITES THIS DATA TO THE RESULT FILE
C
      SUBROUTINE DATAIO
C
C---SPECIFICATIONS
C
C---THE FOLLOWING CARD MUST BE CHANGED IF PROBLEM DIMENSIONS ARE
C   GREATER THAN 30,000. ALSO CHANGE VALUE OF IMAXX IN
c   MAIN PROGRAM
      PARAMETER (IMAXX=30000)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION QWELL(IMAXX)
      DIMENSION IHR(2),IDY(2)
      CHARACTER STRING*140,TITLE*100,WELLID*20,CDATE(IMAXX)*10
      CHARACTER*4 YEAR
      CHARACTER*2 DAY, MONTH, HR
      CHARACTER*10 TEMPDT
C
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ XWELL,DIFFUS,SLEAK,QWINIT
      COMMON /PAR2/ ISOLN,INTIME,NPD
      COMMON /PAR7/ CDATE,QWELL
      COMMON /HUNT/ TRANS, STOR, SIGMA, RKPRME, BP
      COMMON /TSTEP/ DELT
C
C13a-WRITE PROGRAM BANNER TO RESULT FILE
      CALL BANNER(IO)
C
C13b-READ INPUT DATA
      READ(IN,'(A140)') STRING
      ILINE=1
      READ(STRING,98,ERR=1000) TITLE
C
      READ(IN,'(A140)') STRING
      ILINE=2
      READ(STRING,99,ERR=1000) WELLID
C
      READ(IN,'(A140)') STRING
      ILINE=3
      READ(STRING,*,ERR=1000) XWELL, DIFFUS, ISOLN, SLEAK, STOR, SIGMA,
     1   BPP, BP, RKPRME, STRWTH, DELT
C.....SET DELT TO 1.0 IF IT IS READ IN AS ZERO...
      IF(DABS(DELT) .LT. 0.01)DELT=1.0D0
C
      IF(ISOLN .EQ. 2)THEN
        TRANS=DIFFUS
      ELSEIF(ISOLN .EQ. 3)THEN
        TRANS=DIFFUS
C.......IF K' IS ZERO, USE INPUT LEAKAGE COEF, OTHERWISE COMPUTE USING K'
        IF(DABS(RKPRME) .GT. 1.0e-20)SLEAK=RKPRME*STRWTH/BPP
      ENDIF
C
      READ(IN,'(A120)') STRING
      ILINE=4
      READ(STRING,*,ERR=1000) INTIME, QWINIT 
C
      READ(IN,'(A100)') STRING
      ILINE=5
      READ(STRING,*,ERR=1000) NPD 
C
C13c-READ STRESS DATA
       DO 10 ID=1,NPD
         READ(IN,'(A120)') STRING
         ILINE=6
         READ(STRING,*,ERR=1000) CDATE(ID), QWELL(ID)
  10   CONTINUE
C
C...CHECK STRESS DATA AGAINST DELT
      IF(NPD .GT. 1)THEN
        IF(DELT .GT. 28)THEN
            WRITE(6,*)' CANNOT USE TIME STEPS GREATER THAN 28 DAYS'
            STOP
        ENDIF
        DO I=1,2
            TEMPDT=CDATE(I)
            YEAR=TEMPDT(1:4)
            MONTH=TEMPDT(5:6)
            DAY=TEMPDT(7:8)
            HR=TEMPDT(9:10)
c........read from strings to convert from character to number
            READ(YEAR, '(I4)') IYR
            READ(MONTH, '(I2)') IMON
            READ(DAY, '(I2)') IDY(I)
            READ(HR,'(I2)') IHR(I)
        ENDDO
        CHKDT=FLOAT(IDY(2)-IDY(1))+FLOAT(IHR(2)-IHR(1))/24.0D0
        IF(DABS(CHKDT) .LT. 0.01)CHKDT=1.0D0
        EPS=DELT-CHKDT
        IF(DABS(EPS) .GT. 0.01)THEN
            WRITE(6,*) ' CHECK HOURS IN TIME STRING FOR STRESS INPUT'
            WRITE(6,*) ' INPUT DELT:', DELT
            WRITE(6,*) ' HOURS FOR FIRST TWO STRESSES:', IHR(1), IHR(2)
            WRITE(6,*) ' STRESSES TIME STEP IN DAYS', CHKDT
            STOP
        ENDIF
      ENDIF
        
C
C13d-WRITE INPUT DATA TO RESULT FILE
C
C---LINE 1 
      WRITE(IO,100)TITLE
C
      WRITE(IO,101)
C
C---LINES 2 AND 3
      WRITE(IO,102)WELLID
      WRITE(IO,103)XWELL
      IF(ISOLN .LE. 1)WRITE(IO,104)DIFFUS
      IF(ISOLN .EQ. 2)WRITE(IO,904)TRANS,STOR
      IF(ISOLN .EQ. 3)WRITE(IO,905)TRANS,RKPRME,STOR,SIGMA,STRWTH,BP,BPP
C
      IF(ISOLN.EQ.0)WRITE(IO,105)ISOLN
      IF(ISOLN.EQ.1)WRITE(IO,106)ISOLN
      IF(ISOLN.EQ.2)WRITE(IO,901)ISOLN
      IF(ISOLN.EQ.3)WRITE(IO,902)ISOLN
      IF(ISOLN.GT.3)THEN
       WRITE(IO,107)
       STOP
      ENDIF
C
      IF(ISOLN.EQ.1)WRITE(IO,108)SLEAK
      IF(ISOLN.GE.2)WRITE(IO,906)SLEAK
C
      IF(ISOLN.EQ.1)THEN
       IF(SLEAK.LE.0.0D0)THEN
        WRITE(IO,109)
        STOP
       ENDIF
      ENDIF
C
C---LINE 4 
      WRITE(IO,110)INTIME
      WRITE(IO,111)QWINIT
C
C---LINES 5 AND HIGHER
      WRITE(IO,112)NPD
      WRITE(IO,113)DELT
C
C---FORMAT STATEMENTS
   98 FORMAT(A70)
   99 FORMAT(A20)
  100 FORMAT(5X,A70)
  101 FORMAT(/,/,20X,'SUMMARY OF INPUT DATA',
     2/,20X,'---------------------'/)
  102 FORMAT(2X,' WELL IDENTIFIER: ',20X,A20)
  103 FORMAT(2X,' WELL DISTANCE TO STREAM (XWELL): ',3X,D10.3,
     2' feet')
  104 FORMAT(2X,' DIFFUSIVITY (DIFFUS): ',12X,D12.3,
     2' square feet per second')
  105 FORMAT(2X,' STREAMBANK CODE (ISOLN): ',8X,I5,
     2' (semipervious streambank absent, Jenkins 1968)')
  106 FORMAT(2X,' STREAMBANK CODE (ISOLN): ',8X,I5,
     2' (semipervious streambank simulated, Hantush, 1965)')
  107 FORMAT(3X,'STREAMBANK CODE (IXA) INVALID. PROGRAM STOPPED.')
  108 FORMAT(2X,' STREAMBANK LEAKANCE (SLEAK): ',7X,D10.3,
     2' feet')
  109 FORMAT(3X,'STREAMBANK LEAKANCE (SLEAK) LESS THAN OR EQUAL',
     2' TO ZERO.',/,5X,' PROGRAM STOPPED.')
  110 FORMAT(2X,' INITIAL TIME (INTIME): ',13X,I5,' days')
  111 FORMAT(2X,' INITIAL PUMPING RATE (QWINIT): ',3X,D12.3,
     2' cubic feet per second')
  112 FORMAT(2X,' NUMBER OF PUMPING STEPS (NPD): ',5X,I5)
  113 FORMAT(2X,' TIME STEP FOR PUMPING  (DELT): ',3X,D12.3, ' days') 
  901 FORMAT(2X,' STREAMBANK CODE (ISOLN): ',8X,I5,
     2' (partially penetrating stream with resistance, Hunt 1999)')
  902 FORMAT(2X,' STREAMBANK CODE (ISOLN): ',8X,I5,
     2' (stream in overlying aquitard simulated, Hunt 2003)')
  904 FORMAT(2X,' TRANSMISSIVITY: ',18X,D12.3,
     2' square feet per second',/,2X,' STORATIVITY: ',21X,D12.3)
  905 FORMAT(2X,' TRANSMISSIVITY: ',18X,D12.3,
     2' square feet per second',/,
     3       2X,' HYDRAULIC COND. OF UPPER LAYER: ',2X,D12.3,
     3' feet per second',/,
     4       2X,' STORATIVITY: ',21X,D12.3,/,
     5       2X,' SPECIFIC YIELD OF UPPER LAYER: ', 3X,D12.3,/,
     6       2X,' STREAM WIDTH: ',20X,D12.3,
     7' feet',/,
     8       2X,' THICKNESS OF UPPER LAYER: ',8X,D12.3,
     9' feet',/,
     1       2X,' BOT. OF STREAM->TOP OF AQUIFER: ', 2X,D12.3,
     2' feet')
  906 FORMAT(2X,' STREAMBED CONDUCTANCE: ',11X,D12.3,
     1' feet per second')



C
      RETURN
C---CALL RDERR FOR INPUT READ ERRORS
 1000 CALL RDERR(IO,STRING,ILINE)
      END
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE BANNER                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 04/21/00 A          *
C      *                                                      *
C       ******************************************************
C
C14-SUBROUTINE BANNER WRITES A PROGRAM BANNER TO RESULT FILE
C
      SUBROUTINE BANNER(IO)
      WRITE(IO,100)
 100  FORMAT(/,10X,
     2'      *****************************************************',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *         ****  U.S. GEOLOGICAL SURVEY  ****        *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *         *** STRMDEPL08: PROGRAM OUTPUT ***        *',/,
     1 10X,
     2'      *                                                   *',/,
     3 10X,
     4'      *    ONE-DIMENSIONAL MODEL OF STREAMFLOW DEPLETION  *',/,
     5 10X,
     6'      *                                                   *',/,
     7 10X,
     8'      *       BY WELLS, BASED ON ANALYTICAL SOLUTIONS     *',/,
     9 10X,
     &'      *                                                   *',/,
     1 10X,
     2'      *   DEVELOPED BY JENKINS (1968) AND HANTUSH (1965)  *',/,
     3 10X,
     &'      *                                                   *',/,
     1 10X,
     2'      *   MODIFIED TO INCLUDE HUNT (1999, 2003) SOLUTIONS *',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *            VERSION 1.0, JUNE, 2008               *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *****************************************************',
     1/,/)
C
      RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE RDERR                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 05/08/07            *
C      *                                                      *
C       ******************************************************
C
C15-SUBROUTINE RDERR WRITES AN ERROR MESSAGE TO THE RESULT FILE
C   AND STOPS PROGRAM EXECUTION
C
      SUBROUTINE RDERR(IO,STRING,ILINE)
C
C---SPECIFICATIONS
      CHARACTER STRING*80,VAR(7)*40
      DATA VAR/' TITLE',
     2         ' WELLID',
     3         ' XWELL, DIFFUS, ISOLN, SLEAK, STOR, SIGMA, ..',
     3         ' BPP, BP, RKPRME, STRWTH, DELT',
     4         ' INTIME  QWINIT',
     5         ' NPD',
     6         ' TIME-PUMPING DATA'/
C
      WRITE(IO,1)ILINE
      WRITE(IO,'(A80)')STRING
      WRITE(IO,2) VAR(ILINE)
      WRITE(IO,3)

   1  FORMAT(' Aborting due to error in line from input file:',
     2 2X,I5)
   2  FORMAT(' While attempting to read variables',A40)
   3  FORMAT(' Check for incorrect positions or data types...')
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE EXERFC                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 10/01/87            *
C      *              CODE CLEANUP 03/27/96 - RSR             *
C      *                                                      *
C       ******************************************************
C
      SUBROUTINE EXERFC(X,YY,Z)
      DOUBLE PRECISION X, YY, Z
C
C       THIS ROUTINE USES RATIONAL CHEBYSHEV APPROXIMATIONS
C       FOR EVALUATING THE ERROR FUNCTION AND COMPLEMENTARY
C       ERROR FUNCTION IN ORDER TO EVALUATE THE PRODUCT OF
C       EXP(X) AND ERFC(Y)
C
C---Local variables
      DOUBLE PRECISION erf, erfcy, p1(5), p2(9), p3(6), q1(5), q2(9), 
     &                 q3(6), sqrtpi, sump, sumq, y, y2i, yi
      INTEGER i
C
C---Intrinsics
      DOUBLE PRECISION DABS, DEXP
      INTRINSIC DABS, DEXP
C
      DATA p1/3.209377589138469472562D03, 3.774852376853020208137D02, 
     &     1.138641541510501556495D02, 3.161123743870565596947D0, 
     &     1.857777061846031526730D-01/
      DATA q1/2.844236833439170622273D03, 1.282616526077372275645D03, 
     &     2.440246379344441733056D02, 2.360129095234412093499D01, 
     &     1.0D0/
      DATA p2/1.23033935479799725272D03, 2.05107837782607146532D03, 
     &     1.71204761263407058314D03, 8.81952221241769090411D02, 
     &     2.98635138197400131132D02, 6.61191906371416294775D01, 
     &     8.88314979438837594118D00, 5.64188496988670089180D-01, 
     &     2.15311535474403846343D-08/
      DATA q2/1.23033935480374942043D03, 3.43936767414372163696D03, 
     &     4.36261909014324715820D03, 3.29079923573345962678D03, 
     &     1.62138957456669018874D03, 5.37181101862009857509D02, 
     &     1.17693950891312499305D02, 1.57449261107098347253D01, 1.0D0/
      DATA p3/ - 6.58749161529837803157D-04, 
     &     -1.60837851487422766278D-02, -1.25781726111229246204D-01, 
     &     -3.60344899949804439429D-01, -3.05326634961232344035D-01, 
     &     -1.63153871373020978498D-02/
      DATA q3/2.33520497626869185443D-03, 6.05183413124413191178D-02, 
     &     5.27905102951428412248D-01, 1.87295284992346047209D00, 
     &     2.56852019228982242072D00, 1.0D0/
C
C---FOR  Y = 0.0
      IF (YY.EQ.0.0D0) THEN
        Z = DEXP(X)
      ELSE
        y = DABS(YY)
        sump = 0.0D0
        sumq = 0.0D0
C
C---FOR 0.0 < Y <= .46875
        IF (y.LE.0.46875D0) THEN
          DO 10 i = 1, 5
            y2i = y**(2*(i-1))
            sump = sump + p1(i)*y2i
            sumq = sumq + q1(i)*y2i
   10     CONTINUE
          erf = y*sump/sumq
          IF (YY.LT.0.0D0) erf = -erf
          erfcy = 1.0D0 - erf
          Z = DEXP(X)*erfcy
C
C---FOR .46875 < Y <= 4.0
        ELSEIF (y.LE.4.0D0) THEN
          DO 20 i = 1, 9
            yi = y**(i-1)
            sump = sump + p2(i)*yi
            sumq = sumq + q2(i)*yi
   20     CONTINUE
          Z = DEXP(X-y*y)*sump/sumq
          IF (YY.LT.0.0D0) Z = 2.0D0*DEXP(X) - Z
C
C---FOR  Y > 4.0
        ELSE
          DO 30 i = 1, 6
            y2i = y**(-2*(i-1))
            sump = sump + p3(i)*y2i
            sumq = sumq + q3(i)*y2i
   30     CONTINUE
          sqrtpi = 0.5641895835477562869481D0
          Z = sqrtpi + sump/(y*y*sumq)
          Z = DEXP(X-y*y)*Z/y
          IF (YY.LT.0.0D0) Z = 2.0D0*DEXP(X) - Z
        ENDIF
      ENDIF
      RETURN
      END
C
C
C
C      /******************************************************\
C      *                                                      *
C      *                  SUBROUTINE AFILE                    *
C      *                                                      *
C      *            VERSION  AS OF 05/08/07                   *
C      *       Subroutine added by Paul Duda Aqua Terra       *
C      *   For STRMDEPL to be run as an extension to GenScn   *
C      *                                                      *
C      *                 intel compiler call added            *
C      *                    May 2007 - HWR                    *
C      *                                                      *
C      \******************************************************/
C
C   SUBROUTINE AFILE GETS INPUT, RESULT, AND PLOT FILE NAMES FROM
C     THE COMMAND LINE AND OPENS THEM
C
      SUBROUTINE AFILE(IPLOT)
C
C---SPECIFICATIONS
      CHARACTER*50 IFNAME, OFNAME, PFNAME
      CHARACTER*80 CLINE
      INTEGER IN, IO, IP, IPLOT, I, ISTR, IPOS
      COMMON /IOUNIT/ IN,IO,IP
C
      IN = 15
      IO = 16
      IP = 17
C
C     getcl is lahey specific, this line may have to be replaced
C     for other compilers
c      CALL GETCL (CLINE)
C
C     assume there is nothing on the command line
C      IPLOT = -1
C      return
C
C      IF (LENCHR(CLINE).GT.0) THEN
C       there is something on the command line
C
C        ISTR = 0
C        IFNAME = ' '
C        OFNAME = ' '
C        PFNAME = ' '
C
C       parse out file names from command line
C        DO 100 I = 1,80
C          IF (CLINE(I:I).EQ.' ') THEN
C            IF (ISTR.EQ.1) THEN
C              IFNAME = CLINE(IPOS:I-1)
C              ISTR = -1
C            ELSE IF (ISTR.EQ.2) THEN
C              OFNAME = CLINE(IPOS:I-1)
C              ISTR = -2
C            ELSE IF (ISTR.EQ.3) THEN
C              PFNAME = CLINE(IPOS:I-1)
C              ISTR = -3
C            END IF
C          ELSE
C            IF (ISTR.EQ.0) THEN
C              ISTR = 1
C              IPOS = I
C            ELSE IF (ISTR.EQ.-1) THEN
C              ISTR = 2
C              IPOS = I
C            ELSE IF (ISTR.EQ.-2) THEN
C              ISTR = 3
C              IPOS = I
C            END IF
C          END IF
C 100    CONTINUE
C
C        OPEN(IN,FILE=IFNAME,STATUS='OLD',ERR=10)
CC
C        OPEN(IO,FILE=OFNAME,ERR=10)
C
C        IPLOT=0
C        IF(PFNAME.NE.' ')THEN
C          OPEN(IP,FILE=PFNAME,ERR=10)
C          IPLOT=1
C        ENDIF
C      END IF
C 10   CONTINUE
C
C......INTEL COMPILER
       CALL GETARG(1,IFNAME,ISTAT)
       IF(ISTAT .EQ. -1)THEN
C......NOTHING ON COMMAND LINE
           IPLOT=-1
           RETURN
       ELSE
           OPEN(IN,FILE=IFNAME,STATUS='OLD',ERR=10)
       ENDIF
       CALL GETARG(2,OFNAME,ISTAT)
       IF(ISTAT .EQ. -1)THEN
            WRITE(6,*)' ERROR - INFILE SPECIFIED, BUT OUTFILE NOT'
            STOP
       ELSE
            OPEN(IO,FILE=OFNAME,ERR=10)
       ENDIF
       CALL GETARG(3,PFNAME,ISTAT)
       IF(ISTAT .EQ. -1)THEN
            IPLOT=0
            WRITE(6,*)' NO PLOT FILE SPECIFIED'
       ELSE
            IPLOT=1
            OPEN(IP,FILE=PFNAME,ERR=10)
       ENDIF
   10  CONTINUE
C---RETURN AND END
      RETURN
      END

C                        SUBROUTINE FTERM                           
C .. Version current 5/8/2007
C .. Computes "F" term in Hunt 2003 solution                                                           
C... HWR
      SUBROUTINE FTERM(DLAM,ALPHA,DT,F)
      DOUBLE PRECISION DLAM, ALPHA, DT, F
C
      DOUBLE PRECISION Z,X,Y,TERM1,TERM2,PI,SQRTPI,SUM
      PI=3.1415926535897931
      SQRTPI = DSQRT(PI)
C
      Z=(ALPHA*DLAM*DSQRT(DT))/2.0D0 + 1.0D0/(2.0D0*ALPHA*DSQRT(DT))
      IF(DABS(Z) .LT. 3.00D0)THEN
C.....EQUATION (47) IN HUNT 2003
        TERM1=DEXP(-1.0D0/(4.0D0*DT*ALPHA**2))*DSQRT(DT/PI)
        X=DLAM/2.0D0+((DT*ALPHA**2*DLAM**2)/4.0D0)
        Y=(ALPHA*DLAM*DSQRT(DT)/2.0D0)+(1.0D0/(2.0D0*ALPHA*DSQRT(DT)))
        CALL EXERFC(X,Y,TERM2)
        F=TERM1-(ALPHA*DT*DLAM/2.0D0)*TERM2
      ELSE
C.....EQUATION (53) IN HUNT 2003 - PAPER SAYS WAS USED FOR Z>3, BUT 
C.....DID NOT SEE OSCILLATION IN THIS CODE FOR Z UP TO 300..
        TERM1=(DEXP(-1.0D0/(4.0D0*DT*ALPHA**2)))/(2.0D0*ALPHA*Z*SQRTPI)
        TERM2=2.0D0/(DLAM*(1.0D0+(1.0D0/(DLAM*DT*ALPHA**2)))**2)
        SUM=1.0D0-(3.0D0/(2.0D0*Z**2))+(15.0D0/(4.0D0*Z**4))-
     &     (105.0D0/(8.0D0*Z**6))
        F=TERM1*(1.0D0+TERM2*SUM)
      ENDIF
      RETURN
      END
C                        SUBROUTINE GTERM                           
C .. Version current 5/8/2007
C .. Computes "G" term in Hunt 2003 solution                  
C    HWR                                                         
C
      SUBROUTINE GTERM(DK,DEPS,ALPHA,DT,G)
      DOUBLE PRECISION DK, DEPS, ALPHA, DT, G
      DOUBLE PRECISION TERM1, TERM2,PTERM, EPS
C
      DOUBLE PRECISION A,B,ADDTERM,DBESS0,DGAMPSV
      INTEGER IBINOM2
      EPS=1.0D-10
C
C.....EQUATION (52) IN HUNT 2003
      A=DEPS*DK*DT*(1-ALPHA**2)
      B=DK*DT*ALPHA**2
      IF(DABS(DK) .LE. 1.0E-10)THEN
        G=0.0D0
        RETURN
      ENDIF
      IF((A+B) .LT. 80)THEN
        TERM1=DEXP(-(A+B))*DBESS0(2.0D0*DSQRT(A*B))
      ELSE
        TERM1=0.
      ENDIF
      SUM=0.0D0
      ABTERM=(DSQRT(A*B)/(A+B))
      DO I=1,100
        N=I-1
        ADDTERM=IBINOM2(N)*DGAMPSV(2*N+1,A+B)*(ABTERM)**(2*N)
        SUM=SUM+ADDTERM
        IF(DABS(ADDTERM) .LT. EPS)GO TO 10
      ENDDO
 10   CONTINUE
      G=0.50D0*(1.0D0-TERM1+((B-A)/(A+B))*SUM)
      RETURN
      END
C
      INTEGER FUNCTION IFACT(N)
      IFACT=1
      IF(N .LE. 1)THEN
        RETURN
      ENDIF
	DO I=N, 1, -1
		IFACT=IFACT*I
	ENDDO
	return
	END
C	
	INTEGER FUNCTION IBINOM2(N)
C.....FUNCTION REQUIRED IS BINOMIAL COEFFICENT FOR (2N N)
C.....WHICH MAY BE WRITTEN AS  (2N)!/(N!(2N-N)!) = (2N)!/(N!)^2
C     HWR
	IBINOM2=IFACT(2*N)/IFACT(N)**2
	RETURN
	END
C	
	DOUBLE PRECISION FUNCTION DBESS0(X)
C.....MODIFIED BESSEL FUNCTION OF ZERO ORDER, I_0(X)
C.....POLYNOMIAL APPROXIMATION, PG 378 OF 
C     ABRAMOWITZ, M., AND STEGUN, I.A., 1965, HANDBOOK OF MATHEMATICAL
C         FUNCTIONS WITH FORMULAS, GRAPHS, AND MATHEMATICAL TABLES:
C         NEW YORK, DOVER PUBLICATIONS, INC., 1046 P.
C
C     HWR
      DOUBLE PRECISION X, T
      T=X/3.750D0
      IF(X .GE. -3.75 .AND. X .LE. 3.75)THEN
      DBESS0=1.0D0+3.5156229*(T**2)+3.0899424*(T**4)+
     &          1.2067492*(T**6)+0.2659732*(T**8)+
     &          0.360768D-01*(T**10)+0.45813D-02*(T**12)
      ELSEIF(X .GT. 3.75)THEN
      DBESS0=(DEXP(X)/DSQRT(X))*(0.39894228+0.1328592E-01/T
     & +0.225319D-02/(T**2)-0.157565D-02/(T**3)+0.916281D-02/(T**4)
     & -0.2057706D-01/(T**5)+0.2635537D-01/(T**6)-0.1647633D-01/(T**7)
     & +0.392377D-02/(T**8))
      ELSE
        WRITE(6,*) "ERROR IN ARGUMENT TO MODIFIED BESSEL FUNCTION"
        STOP
      ENDIF
      RETURN 
      END
C
      DOUBLE PRECISION FUNCTION FACTLN(N)
C.....FUNCTION FOR FACTORIAL OF INTEGER N
C.....RETURNS LOG(N!) AS DOUBLE PRECISION
C     HWR
	INTEGER N
	DOUBLE PRECISION DBL
      FACTLN=DLOG(1.0D0)
      IF(N .LE. 1)THEN
        RETURN
      ENDIF
	    DO I=N, 1, -1
	     DBL=DBLE(I)
		   FACTLN=FACTLN+DLOG(DBL)
	ENDDO
	RETURN
	END
C
      DOUBLE PRECISION FUNCTION DGAMPSV(N,X)
C.....INCOMPLETE GAMMA FUNCTION, P(N,X)
C.....BECAUSE CALLING PROGRAM HAS N AS AN INTEGER VALUE
C.....CAN BE EVALUATED USING SPECIAL VALUE EXPANSION, PG. 262 OF 
C     ABRAMOWITZ, M., AND STEGUN, I.A., 1965, HANDBOOK OF MATHEMATICAL
C         FUNCTIONS WITH FORMULAS, GRAPHS, AND MATHEMATICAL TABLES:
C         NEW YORK, DOVER PUBLICATIONS, INC., 1046 P.
C
C     HWR
      DOUBLE PRECISION X, TERM, SUM, TERMLN, DFACT, DBL, FACTLN
      INTEGER N, I, IFACT
C.....START SERIERS, 2! = 2
      IF(N .EQ. 1)THEN
	   SUM=1.0D0
	ELSEIF(N .EQ. 2)THEN
	   SUM=1.0D0+X
	ELSE
      SUM=1.0D0+X+(X**2)/2.0D0
      ENDIF
      DO I=3,N-1
      	IF(I .GE. 12)THEN
      		DBL=DBLE(I)
      		TERMLN=DBL*DLOG(X)-FACTLN(I)
      		TERM=DEXP(TERMLN)
        ELSE
      		TERM=(X**I)/DBLE(IFACT(I))
        ENDIF
        SUM=SUM+TERM
      ENDDO
      DGAMPSV=1.0D0-SUM*DEXP(-X)
      IF(DGAMPSV .LT. 0.0D0)DGAMPSV=0.0D0
C.....AS N GETS BIG, SERIES APPROACHES DEXP(X)
C.....SO P(N,X) GOES TO ZERO
      RETURN 
      END	  
      